#[non_exhaustive]pub enum Event<'a> {
Send {
mime_type: String,
fd: BorrowedFd<'a>,
},
Cancelled,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Send
send the primary selection contents
Request for the current primary selection contents from the client. Send the specified mime type over the passed file descriptor, then close it.
Cancelled
request for primary selection contents was canceled
This primary selection source is no longer valid. The client should clean up and destroy this primary selection source.
Implementations